@@ -13,7 +13,7 @@ def cmp(a, b):
 #            D.extend(dofs[node])
 #        return D
                 
-def _offsetIndices(lst, offset=0):
+def _offsetIndices(lst, offset=0):  
     '''Shifts the indices by offset. 
     Positive offsets move the indices away from 0.
     Negative offsets move the indices towards 0.
@@ -278,8 +278,13 @@ class GmshMeshGenerator:
         options += ' ' + self.additionalOptions
         
         #Execute gmsh
+        
         gmshExe = os.path.normpath(gmshExe)
-        os.system('""%s" "%s" %s"' % (gmshExe, geoFilePath, options))
+        print(gmshExe)
+        #print('""%s" "%s" %s"' % (gmshExe, geoFilePath, options))
+        #os.system('""%s" "%s" %s"' % (gmshExe, geoFilePath, options))
+        os.system(r'"%s" "%s" %s' % (gmshExe, geoFilePath, options))
+
         
         #Read generated msh file:
         #print("Opening msh file " + mshFileName)#TEMP
